@@ -9,6 +9,7 @@ from typing import List,Dict,Any,Optional
 class SourceCode(pydantic.BaseModel):
     module_name: str
     source_code: str
+    tag: str = ""
 
 
 class TranslateReadme(pydantic.BaseModel):
@@ -32,7 +33,7 @@ class TranslateArgs(pydantic.BaseModel):
     new_file_mark: str = pydantic.Field(..., description="according to the file suffix, the new file name should be like this: filename-new_file_mark.file_suffix")    
 
 class ExecuteStep(pydantic.BaseModel):
-    code: str = pydantic.Field(..., description="The code line to execute")
+    code: str = pydantic.Field(..., description="The code line to execute, e.g. `print('hello world')` or `ls -l`, shell or python code.")
     lang: str = pydantic.Field(..., description="The language to execute the code line, python,shell. default is python")
     total_steps: Optional[int] = pydantic.Field(-1, description="The total steps to finish the user's question")
     current_step: Optional[int] = pydantic.Field(-1, description="The current step to finish the user's question")
@@ -63,19 +64,45 @@ class AutoCoderArgs(pydantic.BaseModel):
     execute: bool = pydantic.Field(False, description="Execute command line or not")
     package_name: str = pydantic.Field("", description="only works for py-script project type. The package name of the script. default is empty.")
     script_path: str = pydantic.Field("", description="only works for py-script project type. The path to the Python script. default is empty.")
+    image_file: str = ""
+    ray_address: str = ""
+    
+    
     model: str = pydantic.Field("", description="the model name to use")
     model_max_length: int = pydantic.Field(1024, description="the maximum length generated by the model. default is 1024 this only works when model is specified.")
+    model_max_input_length: int = pydantic.Field(6000, description="The maximum input length of the model") 
+    
     file: Optional[str] = pydantic.Field(None, description="the configuration file to use")
     anti_quota_limit: Optional[int] = pydantic.Field(1, description="After how much time to wait for the next request. default is 1s")
     skip_build_index: bool = pydantic.Field(True, description="Skip building index or not. default is True")
     print_request: bool = pydantic.Field(False, description="Print request to model or not. default is False")
     human_as_model: bool = pydantic.Field(False, description="Use human as model or not. default is False")
     py_packages: str = pydantic.Field("", description="The Python packages added to context,only works for py project type. default is empty.")
+    
     urls: str = pydantic.Field("", description="The urls to crawl and extract text from, separated by comma")
+    urls_use_model:bool = True
+
     search_engine: str = ""
     search_engine_token: str = ""
-    model_max_input_length: int = pydantic.Field(6000, description="The maximum input length of the model") 
+    enable_rag_search:bool
+    enable_rag_context:bool
+    required_exts:str = ""
+    
     auto_merge: bool = pydantic.Field(False, description="Whether to automatically merge the generated code into the existing file")
+    vl_model: str = ""
+    sd_model: str = ""
+    emb_model: str = ""
+    
+    index_model: str = ""
+    index_model_max_length: int = pydantic.Field(0, description="the maximum length generated by the model. default is 0 this only works when model is specified.")
+    index_model_max_input_length: int = pydantic.Field(0, description="The maximum input length of the model") 
+    index_model_anti_quota_limit: Optional[int] = pydantic.Field(0, description="After how much time to wait for the next request. default is 0s")
+    index_filter_level: int = 3
+    index_filter_workers: int = 1
+    image_max_iter: int = 1 
+
+    class Config:
+        protected_namespaces = ()
 
 
 def is_likely_useful_file(file_path):
