@@ -9,6 +9,8 @@ import importlib
 import byzerllm
 import importlib
 import pkgutil
+from autocoder.common.search import Search,SearchEngine
+from autocoder.rag.simple_rag import SimpleRAG
 
 class Level1PyProject():
     
@@ -120,6 +122,7 @@ class PyProject():
                     continue
                 module_path = spec.origin
                 source_code = self.convert_to_source_code(module_path)
+                source_code.tag = "PACKAGE"
                 if source_code is not None:
                     yield source_code
         except ModuleNotFoundError:
@@ -127,10 +130,34 @@ class PyProject():
 
     def get_rest_source_codes(self) -> Generator[SourceCode, None, None]:
         if self.args.urls:
-            http_doc = HttpDoc(urls=self.args.urls.split(","), llm=self.llm)
+            http_doc = HttpDoc(args=self.args, llm=self.llm,urls=self.args.urls.split(","))
             sources = http_doc.crawl_urls()         
+            for source in sources:
+                source.tag = "REST"                
             return sources
-        return []    
+        return []  
+    
+    def get_rag_source_codes(self):
+        if self.args.enable_rag_search:
+            rag = SimpleRAG(self.llm,self.args,self.args.source_dir)
+            docs = rag.search(self.args.query)
+            for doc in docs:
+                doc.tag = "RAG"
+            return docs
+        return  []
+
+    def get_search_source_codes(self):
+        temp = self.get_rag_source_codes()
+        if self.args.search_engine and self.args.search_engine_token:
+            if self.args.search_engine == "bing":
+                search_engine = SearchEngine.BING
+            else:
+                search_engine = SearchEngine.GOOGLE
+
+            searcher=Search(llm=self.llm,search_engine=search_engine,subscription_key=self.args.search_engine_token)
+            search_context = searcher.answer_with_the_most_related_context(self.args.query)  
+            return temp + [SourceCode(module_name="SEARCH_ENGINE", source_code=search_context,tag="SEARCH")]
+        return temp + []    
 
     def get_source_codes(self)->Generator[SourceCode,None,None]:        
         for root, dirs, files in os.walk(self.directory):
@@ -152,6 +179,11 @@ class PyProject():
                 print(f"##File: {code.module_name}")
                 print(code.source_code)
 
+            for code in self.get_search_source_codes():
+                self.sources.append(code)
+                print(f"##File: {code.module_name}")
+                print(code.source_code)    
+
             for package in packages:
                 for code in self.get_package_source_codes(package):
                     self.sources.append(code)
@@ -169,6 +201,11 @@ class PyProject():
                     self.sources.append(code)
                     file.write(f"##File: {code.module_name}\n")
                     file.write(f"{code.source_code}\n\n")
+
+                for code in self.get_search_source_codes():
+                    self.sources.append(code)
+                    file.write(f"##File: {code.module_name}\n")
+                    file.write(f"{code.source_code}\n\n")    
                 
                 for package in packages:
                     for code in self.get_package_source_codes(package):
