@@ -1,11 +1,13 @@
 from autocoder.common import SourceCode,AutoCoderArgs
 from autocoder import common as FileUtils  
 from autocoder.utils.rest import HttpDoc
+from autocoder.rag.simple_rag import SimpleRAG
 import os
 from typing import Optional,Generator,List,Dict,Any
 
 from git import Repo
 import byzerllm
+from autocoder.common.search import Search,SearchEngine
 
 class TSProject():
     
@@ -95,10 +97,34 @@ class TSProject():
                     
     def get_rest_source_codes(self) -> Generator[SourceCode, None, None]:
         if self.args.urls:
-            http_doc = HttpDoc(urls=self.args.urls.split(","), llm=self.llm)
-            sources = http_doc.crawl_urls()         
+            http_doc = HttpDoc(args = self.args, llm=self.llm,urls=self.args.urls.split(","))
+            sources = http_doc.crawl_urls()  
+            for source in sources:
+                source.tag = "REST"       
             return sources
-        return []  
+        return [] 
+    
+    def get_rag_source_codes(self):
+        if self.args.enable_rag_search:
+            rag = SimpleRAG(self.llm,self.args,self.args.source_dir)
+            docs = rag.search(self.args.query)
+            for doc in docs:
+                doc.tag = "RAG"
+            return docs
+        return  []
+
+    def get_search_source_codes(self):
+        temp = self.get_rag_source_codes()
+        if self.args.search_engine and self.args.search_engine_token:
+            if self.args.search_engine == "bing":
+                search_engine = SearchEngine.BING
+            else:
+                search_engine = SearchEngine.GOOGLE
+
+            searcher=Search(llm=self.llm,search_engine=search_engine,subscription_key=self.args.search_engine_token)
+            search_context = searcher.answer_with_the_most_related_context(self.args.query)  
+            return temp + [SourceCode(module_name="SEARCH_ENGINE", source_code=search_context,tag="SEARCH")]
+        return temp + []       
 
     def run(self):
         if self.git_url is not None:
@@ -110,6 +136,11 @@ class TSProject():
                 print(f"##File: {code.module_name}")
                 print(code.source_code)
 
+            for code in self.get_search_source_codes():
+                self.sources.append(code)
+                print(f"##File: {code.module_name}")
+                print(code.source_code)    
+
             for code in self.get_source_codes():
                 self.sources.append(code)
                 print(f"##File: {code.module_name}")
@@ -120,6 +151,11 @@ class TSProject():
                     self.sources.append(code)
                     file.write(f"##File: {code.module_name}\n")
                     file.write(f"{code.source_code}\n\n")
+
+                for code in self.get_search_source_codes():
+                    self.sources.append(code)
+                    file.write(f"##File: {code.module_name}\n")
+                    file.write(f"{code.source_code}\n\n")    
                     
                 for code in self.get_source_codes():
                     self.sources.append(code)
